@@ -70,6 +70,47 @@ credentials_file_provider <- function() {
   return(creds)
 }
 
+# Retrieve container job role credentials
+container_credentials_provider <- function() {
+
+  # Initialize to NULL
+  credentials_response <- NULL
+
+  container_credentials_uri <-
+    Sys.getenv("AWS_CONTAINER_CREDENTIALS_RELATIVE_URI")
+
+  # Look for job role credentials first
+  if (container_credentials_uri != "") {
+    credentials_response <- get_container_credentials()
+  }
+
+  if (is.null(credentials_response)) return(NULL)
+
+  credentials_response_body <-
+    jsonlite::fromJSON(rawToChar(credentials_response$body))
+
+  access_key_id <- credentials_response_body$AccessKeyId
+  secret_access_key <- credentials_response_body$SecretAccessKey
+  session_token <- credentials_response_body$Token
+
+  if (is.null(access_key_id) || is.null(secret_access_key) ||
+      is.null(session_token)) return(NULL)
+
+  if (access_key_id != "" && secret_access_key != "" &&
+      session_token != "") {
+    creds <- list(
+      access_key_id = access_key_id,
+      secret_access_key = secret_access_key,
+      session_token = session_token,
+      provider_name = ""
+    )
+  } else {
+    creds <- NULL
+  }
+  return(creds)
+}
+
+
 # Retrieve credentials for EC2 IAM Role
 iam_credentials_provider <- function() {
 
@@ -79,7 +120,7 @@ iam_credentials_provider <- function() {
   credentials_url <- file.path("iam/security-credentials", iam_role)
 
   credentials_response <- get_instance_metadata(credentials_url)
-
+  
   if (is.null(credentials_response)) return(NULL)
 
   credentials_response_body <- jsonlite::fromJSON(rawToChar(credentials_response$body))
@@ -103,7 +144,6 @@ iam_credentials_provider <- function() {
     creds <- NULL
   }
   return(creds)
-
 }
 
 no_credentials <- function() {
