@@ -2,19 +2,22 @@
 #' @include credential_providers.R
 NULL
 
+Creds <- struct(
+  access_key_id = "",
+  secret_access_key = "",
+  session_token = "",
+  provider_name = ""
+)
+
 Credentials <- struct(
-  creds = list(
-    access_key_id = "",
-    secret_access_key = "",
-    session_token = "",
-    provider_name = ""
-  ),
+  creds = Creds(),
   profile = "",
   force_refresh = TRUE,
   provider = list(
     r_env_provider,
     os_env_provider,
     credentials_file_provider,
+    container_credentials_provider,
     iam_credentials_provider,
     no_credentials
   )
