@@ -205,10 +205,15 @@ xml_parse_structure <- function(node, interface) {
     return(result)
   }
 
-  result <- list()
+  result <- interface
   for (name in names(interface)) {
     field <- interface[[name]]
 
+    # Skip fields that don't come from the response body.
+    if (tag_get(field, "location") != "") {
+      next
+    }
+
     node_name <- name
     flattened <- tag_get(field, "flattened") != ""
     if (flattened && tag_get(field, "locationNameList") != "") {
@@ -222,10 +227,6 @@ xml_parse_structure <- function(node, interface) {
       elem <- node[names(node) == node_name]
     }
 
-    if (length(elem) == 0) {
-      # TODO: Implement.
-    }
-
     parsed <- xml_parse(elem, field)
 
     result[[name]] <- parsed
